@@ -13,8 +13,8 @@ file_extensions = OrderedDict(
         ("msi", (b".msi", b".msp", b".appx")),
         ("pub", (b".pub",)),
         ("doc", (b".doc", b".dot", b".docx", b".dotx", b".docm", b".dotm", b".docb", b".rtf", b".mht", b".mso", b".wbk")),
-        ("xls", (b".xls", b".xlt", b".xlm", b".xlsx", b".xltx", b".xlsm", b".xltm", b".xlsb", b".xla", b".xlam", b".xll", b".xlw", b".slk")),
-        ("ppt", (b".ppt", b".pot", b".pps", b".pptx", b".pptm", b".potx", b".potm", b".ppam", b".ppsx", b".ppsm", b".sldx", b".sldm")),
+        ("xls", (b".xls", b".xlt", b".xlm", b".xlsx", b".xltx", b".xlsm", b".xltm", b".xlsb", b".xla", b".xlam", b".xll", b".xlw", b".slk", b".xll", b".csv")),
+        ("ppt", (b".ppt", b".ppa", b".pot", b".pps", b".pptx", b".pptm", b".potx", b".potm", b".ppam", b".ppsx", b".ppsm", b".sldx", b".sldm")),
         ("jar", (b".jar",)),
         # ("rar", (b".rar",)),
         ("swf", (b".swf", b".fws")),
@@ -38,7 +38,7 @@ file_extensions = OrderedDict(
         ("msbuild", (b".csproj", b".vbproj", b".vcxproj", b".dbproj", b".fsproj")),
         ("zip", (b".zip",)),
         ("cpl", (b".cpl",)),
-        ("xls", (b".xll",)),
+        ("ichitaro", (b".jtd", b".jtdc", b".jttc", b".jtt"))
     ]
 )
 
@@ -229,6 +229,9 @@ def office_ole(f):
 
 
 def powershell(f):
+    if f.contents.startswith(b"MZ"):
+        return None
+
     POWERSHELL_STRS = [
         b"$PSHOME",
         b"Get-WmiObject",
@@ -251,6 +254,9 @@ def powershell(f):
 
 
 def javascript(f):
+    if f.contents.startswith(b"MZ"):
+        return None
+
     JS_STRS = [
         b"var ",
         b"function ",
@@ -296,6 +302,9 @@ def pub(f):
 
 
 def visualbasic(f):
+    if f.contents.startswith(b"MZ"):
+        return None
+
     VB_STRS = [
         b"Dim ",
         b"dim ",
